==> 0.0.3.tar.gz: lib/models/data.dart <==
import 'profile.dart';

class HeaderModel {
  final int id;
  int version;
  final String number;
  String? subject;
  String? summary;
  double? value;
  String? currencyCode;
  bool flag;
  final DateTime received;
  bool read;
  HeaderModel(this.id, this.version, this.number, this.subject, this.value,
      this.currencyCode, this.flag, this.received, this.read, this.summary);
  factory HeaderModel.fromJson(Map<String, dynamic> json) {
    return HeaderModel(
      json['id'],
      json['version'],
      json['number'],
      json['subject'],
      json['value'] is int ? json['value'].toDouble() : json['value'],
      json['currencyCode'],
      json['flag'],
      DateTime.parse(json['received']),
      json['read'],
      json['summary'],
    );
  }

  void update(RecipientModel snapshot) {
    version = snapshot.version;
    subject = snapshot.subject;
    value = snapshot.value;
    currencyCode = snapshot.currencyCode;
  }
}

class RecipientModel extends HeaderModel {
  final String form;
  final dynamic data;
  final dynamic extra;
  final List<Comment> comments;
  final List<Entry> cubes;
  final List<Attachment> attachments;
  final List<Sibling> recipients;
  final String folderId;
  final int documentId;
  final bool fyi;
  List<String>? actions;
  DateTime? viewed;
  int unreadComments;
  bool draft;
  bool pending;
  bool escalated;
  RecipientModel(
      int id,
      int version,
      String number,
      String? subject,
      double? value,
      String? currencyCode,
      this.fyi,
      this.data,
      this.form,
      this.actions,
      this.recipients,
      this.comments,
      this.cubes,
      this.attachments,
      this.viewed,
      this.unreadComments,
      this.documentId,
      this.folderId,
      bool flag,
      DateTime received,
      bool read,
      this.draft,
      this.pending,
      this.escalated,
      String? summary,
      this.extra)
      : super(
          id,
          version,
          number,
          subject,
          value,
          currencyCode,
          flag,
          received,
          read,
          summary,
        );

  factory RecipientModel.fromJson(Map<String, dynamic> json) {
    return RecipientModel(
      json['id'],
      json['version'],
      json['number'],
      json['subject'],
      json['value'] is int ? json['value'].toDouble() : json['value'],
      json['currencyCode'],
      json['fyi'],
      json['model'],
      json['form'],
      List.from(json.containsKey('actions') ? json['actions'] : []),
      List<Sibling>.from(json['recipients'].map((e) => Sibling.fromJson(e))),
      List<Comment>.from(json['comments'].map((e) => Comment.fromJson(e))),
      List<Entry>.from(json['cubes'].map((e) => Entry.fromJson(e))),
      List<Attachment>.from(
          json['attachments'].map((e) => Attachment.fromJson(e))),
      //json.containsKey('viewed') ? DateTime.parse(json['viewed']) : null,
      null,
      json['unreadComments'],
      json['documentId'],
      json['folderId'],
      json['flag'],
      DateTime.parse(json['received']),
      json['read'],
      json['draft'],
      json['pending'],
      json['escalated'],
      json['summary'],
      json['extra'],
    );
  }

  @override
  void update(RecipientModel snapshot) {
    version = snapshot.version;
    actions = snapshot.actions;
    subject = snapshot.subject;
    summary = snapshot.summary;
    data.addAll(snapshot.data);
    attachments.clear();
    attachments.addAll(snapshot.attachments);
    super.update(snapshot);
  }
}

class Attachment {
  final int id;
  final String userId;
  final DateTime time;
  final String fileName;
  final String contentType;
  final bool? deleted;
  final AttachmentMode mode;
  final String? holdingId;
  Attachment(this.id, this.userId, this.time, this.fileName, this.contentType,
      this.deleted, this.mode, this.holdingId);
  factory Attachment.fromJson(Map<String, dynamic> json) {
    return Attachment(
        json['id'],
        json['userId'],
        DateTime.parse(json['time']),
        json['fileName'],
        json['contentType'],
        json['deleted'],
        json['mode'],
        json['holdingId']);
  }
}

enum AttachmentMode { public, private, checkedOut, checkedIn }

class Sibling {
  final int id;
  final String userId;
  final DateTime received;
  final bool? pending;
  final bool? fyi;
  final bool? escalated;
  final bool? estimate;
  final DateTime? replied;
  final String? action;
  final String? role;

  Sibling(this.id, this.userId, this.received, this.pending, this.fyi,
      this.escalated, this.estimate, this.replied, this.action, this.role);
  factory Sibling.fromJson(Map<String, dynamic> json) {
    return Sibling(
        json['id'],
        json['userId'],
        DateTime.parse(json['received']),
        json['pending'],
        json['fyi'],
        json['escalated'],
        json['estimate'],
        json['replied'] != null ? DateTime.parse(json['replied']) : null,
        json['action'],
        json['role']);
  }
}

class Comment {
  final int id;
  String? text;

  /// base64
  String? image;
  final String userId;
  final String? byId;
  late String? name;
  final DateTime time;
  DateTime? edited;
  Map<String, dynamic>? resource;
  Comment(this.id, this.userId, this.text, this.time, this.resource, this.byId,
      this.edited, this.image);
  factory Comment.fromJson(Map<String, dynamic> json) {
    return Comment(
        json['id'],
        json['userId'],
        json['text'],
        DateTime.parse(json['time']),
        json['resource'],
        json['byId'],
        json['edited'] != null ? DateTime.parse(json['edited']) : null,
        json['image']);
  }
  update(Comment other) {
    text = other.text;
    resource = other.resource;
    edited = other.edited;
  }
}

class Entry {
  final String cube;
  final double value;
  final List<String> axes;
  Entry(this.cube, this.value, this.axes);
  factory Entry.fromJson(Map<String, dynamic> json) {
    return Entry(
        json['cube'],
        json['value'] is int ? json['value'].toDouble() : json['value'],
        List.from(json['axes']));
  }
}

==> 0.0.8.tar.gz: lib/models/data.dart <==
class HeaderModel {
  final int id;
  int version;
  final String number;
  String? subject;
  String? summary;
  double? value;
  String? currencyCode;
  bool flag;
  final DateTime received;
  bool read;
  HeaderModel(this.id, this.version, this.number, this.subject, this.value,
      this.currencyCode, this.flag, this.received, this.read, this.summary);
  factory HeaderModel.fromJson(Map<String, dynamic> json) {
    return HeaderModel(
      json['id'],
      json['version'],
      json['number'],
      json['subject'],
      json['value'] is int ? json['value'].toDouble() : json['value'],
      json['currencyCode'],
      json['flag'],
      DateTime.parse(json['received']),
      json['read'],
      json['summary'],
    );
  }

  void update(RecipientModel snapshot) {
    version = snapshot.version;
    subject = snapshot.subject;
    value = snapshot.value;
    currencyCode = snapshot.currencyCode;
  }
}

class RecipientModel extends HeaderModel {
  final String form;
  final dynamic data;
  final dynamic extra;
  final List<Comment> comments;
  final List<Entry> cubes;
  final List<Attachment> attachments;
  final List<Sibling> recipients;
  final String folderId;
  final int documentId;
  final bool fyi;
  List<String>? actions;
  DateTime? viewed;
  int unreadComments;
  bool draft;
  bool pending;
  bool escalated;
  RecipientModel(
      int id,
      int version,
      String number,
      String? subject,
      double? value,
      String? currencyCode,
      this.fyi,
      this.data,
      this.form,
      this.actions,
      this.recipients,
      this.comments,
      this.cubes,
      this.attachments,
      this.viewed,
      this.unreadComments,
      this.documentId,
      this.folderId,
      bool flag,
      DateTime received,
      bool read,
      this.draft,
      this.pending,
      this.escalated,
      String? summary,
      this.extra)
      : super(
          id,
          version,
          number,
          subject,
          value,
          currencyCode,
          flag,
          received,
          read,
          summary,
        );

  factory RecipientModel.fromJson(Map<String, dynamic> json) {
    return RecipientModel(
      json['id'],
      json['version'],
      json['number'],
      json['subject'],
      json['value'] is int ? json['value'].toDouble() : json['value'],
      json['currencyCode'],
      json['fyi'],
      json['model'],
      json['form'],
      List.from(json.containsKey('actions') ? json['actions'] : []),
      List<Sibling>.from(json['recipients'].map((e) => Sibling.fromJson(e))),
      List<Comment>.from(json['comments'].map((e) => Comment.fromJson(e))),
      List<Entry>.from(json['cubes'].map((e) => Entry.fromJson(e))),
      List<Attachment>.from(
          json['attachments'].map((e) => Attachment.fromJson(e))),
      //json.containsKey('viewed') ? DateTime.parse(json['viewed']) : null,
      null,
      json['unreadComments'],
      json['documentId'],
      json['folderId'],
      json['flag'],
      DateTime.parse(json['received']),
      json['read'],
      json['draft'],
      json['pending'],
      json['escalated'],
      json['summary'],
      json['extra'],
    );
  }

  @override
  void update(RecipientModel snapshot) {
    version = snapshot.version;
    actions = snapshot.actions;
    subject = snapshot.subject;
    summary = snapshot.summary;
    data.addAll(snapshot.data);
    attachments.clear();
    attachments.addAll(snapshot.attachments);
    super.update(snapshot);
  }
}

class Attachment {
  final int id;
  final String userId;
  final DateTime time;
  final String fileName;
  final String contentType;
  final bool? deleted;
  final bool? private;
  final bool? checkedOut;
  final String? holdingId;
  Attachment(this.id, this.userId, this.time, this.fileName, this.contentType,
      this.deleted, this.private, this.checkedOut, this.holdingId);
  factory Attachment.fromJson(Map<String, dynamic> json) {
    return Attachment(
        json['id'],
        json['userId'],
        DateTime.parse(json['time']),
        json['fileName'],
        json['contentType'],
        json['deleted'],
        json['private'],
        json['checkedOut'],
        json['holdingId']);
  }
}

enum AttachmentMode { public, private, checkedOut, checkedIn }

class Sibling {
  final int id;
  final String userId;
  final DateTime received;
  final bool? pending;
  final bool? fyi;
  final bool? escalated;
  final bool? estimate;
  final DateTime? replied;
  final String? action;
  final String? role;

  Sibling(this.id, this.userId, this.received, this.pending, this.fyi,
      this.escalated, this.estimate, this.replied, this.action, this.role);
  factory Sibling.fromJson(Map<String, dynamic> json) {
    return Sibling(
        json['id'],
        json['userId'],
        DateTime.parse(json['received']),
        json['pending'],
        json['fyi'],
        json['escalated'],
        json['estimate'],
        json['replied'] != null ? DateTime.parse(json['replied']) : null,
        json['action'],
        json['role']);
  }
}

class Comment {
  final int id;
  String? text;

  /// base64
  String? image;
  final String userId;
  final String? byId;
  late String? name;
  final DateTime time;
  DateTime? edited;
  Map<String, dynamic>? resource;
  Comment(this.id, this.userId, this.text, this.time, this.resource, this.byId,
      this.edited, this.image);
  factory Comment.fromJson(Map<String, dynamic> json) {
    return Comment(
        json['id'],
        json['userId'],
        json['text'],
        DateTime.parse(json['time']),
        json['resource'],
        json['byId'],
        json['edited'] != null ? DateTime.parse(json['edited']) : null,
        json['image']);
  }
  update(Comment other) {
    text = other.text;
    resource = other.resource;
    edited = other.edited;
  }
}

class Entry {
  final String cube;
  final double value;
  final List<String> axes;
  Entry(this.cube, this.value, this.axes);
  factory Entry.fromJson(Map<String, dynamic> json) {
    return Entry(
        json['cube'],
        json['value'] is int ? json['value'].toDouble() : json['value'],
        List.from(json['axes']));
  }
}
